==> openshift-model-hive-6.9.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ControlPlaneServingCertificateSpecFluent.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ControlPlaneServingCertificateSpecFluent<A extends ControlPlaneServingCertificateSpecFluent<A>> extends BaseFluent<A>{
  public ControlPlaneServingCertificateSpecFluent() {
  }
  
  public ControlPlaneServingCertificateSpecFluent(ControlPlaneServingCertificateSpec instance) {
    this.copyInstance(instance);
  }
  private ArrayList<ControlPlaneAdditionalCertificateBuilder> additional = new ArrayList<ControlPlaneAdditionalCertificateBuilder>();
  private String _default;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ControlPlaneServingCertificateSpec instance) {
    instance = (instance != null ? instance : new ControlPlaneServingCertificateSpec());
  
    if (instance != null) {
        this.withAdditional(instance.getAdditional());
        this.withDefault(instance.getDefault());
        this.withAdditional(instance.getAdditional());
        this.withDefault(instance.getDefault());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public A addToAdditional(int index,ControlPlaneAdditionalCertificate item) {
    if (this.additional == null) {this.additional = new ArrayList<ControlPlaneAdditionalCertificateBuilder>();}
    ControlPlaneAdditionalCertificateBuilder builder = new ControlPlaneAdditionalCertificateBuilder(item);
    if (index < 0 || index >= additional.size()) { _visitables.get("additional").add(builder); additional.add(builder); } else { _visitables.get("additional").add(index, builder); additional.add(index, builder);}
    return (A)this;
  }
  
  public A setToAdditional(int index,ControlPlaneAdditionalCertificate item) {
    if (this.additional == null) {this.additional = new ArrayList<ControlPlaneAdditionalCertificateBuilder>();}
    ControlPlaneAdditionalCertificateBuilder builder = new ControlPlaneAdditionalCertificateBuilder(item);
    if (index < 0 || index >= additional.size()) { _visitables.get("additional").add(builder); additional.add(builder); } else { _visitables.get("additional").set(index, builder); additional.set(index, builder);}
    return (A)this;
  }
  
  public A addToAdditional(io.fabric8.openshift.api.model.hive.v1.ControlPlaneAdditionalCertificate... items) {
    if (this.additional == null) {this.additional = new ArrayList<ControlPlaneAdditionalCertificateBuilder>();}
    for (ControlPlaneAdditionalCertificate item : items) {ControlPlaneAdditionalCertificateBuilder builder = new ControlPlaneAdditionalCertificateBuilder(item);_visitables.get("additional").add(builder);this.additional.add(builder);} return (A)this;
  }
  
  public A addAllToAdditional(Collection<ControlPlaneAdditionalCertificate> items) {
    if (this.additional == null) {this.additional = new ArrayList<ControlPlaneAdditionalCertificateBuilder>();}
    for (ControlPlaneAdditionalCertificate item : items) {ControlPlaneAdditionalCertificateBuilder builder = new ControlPlaneAdditionalCertificateBuilder(item);_visitables.get("additional").add(builder);this.additional.add(builder);} return (A)this;
  }
  
  public A removeFromAdditional(io.fabric8.openshift.api.model.hive.v1.ControlPlaneAdditionalCertificate... items) {
    if (this.additional == null) return (A)this;
    for (ControlPlaneAdditionalCertificate item : items) {ControlPlaneAdditionalCertificateBuilder builder = new ControlPlaneAdditionalCertificateBuilder(item);_visitables.get("additional").remove(builder); this.additional.remove(builder);} return (A)this;
  }
  
  public A removeAllFromAdditional(Collection<ControlPlaneAdditionalCertificate> items) {
    if (this.additional == null) return (A)this;
    for (ControlPlaneAdditionalCertificate item : items) {ControlPlaneAdditionalCertificateBuilder builder = new ControlPlaneAdditionalCertificateBuilder(item);_visitables.get("additional").remove(builder); this.additional.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromAdditional(Predicate<ControlPlaneAdditionalCertificateBuilder> predicate) {
    if (additional == null) return (A) this;
    final Iterator<ControlPlaneAdditionalCertificateBuilder> each = additional.iterator();
    final List visitables = _visitables.get("additional");
    while (each.hasNext()) {
      ControlPlaneAdditionalCertificateBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ControlPlaneAdditionalCertificate> buildAdditional() {
    return additional != null ? build(additional) : null;
  }
  
  public ControlPlaneAdditionalCertificate buildAdditional(int index) {
    return this.additional.get(index).build();
  }
  
  public ControlPlaneAdditionalCertificate buildFirstAdditional() {
    return this.additional.get(0).build();
  }
  
  public ControlPlaneAdditionalCertificate buildLastAdditional() {
    return this.additional.get(additional.size() - 1).build();
  }
  
  public ControlPlaneAdditionalCertificate buildMatchingAdditional(Predicate<ControlPlaneAdditionalCertificateBuilder> predicate) {
    for (ControlPlaneAdditionalCertificateBuilder item: additional) { if(predicate.test(item)){ return item.build();} } return null;
  }
  
  public boolean hasMatchingAdditional(Predicate<ControlPlaneAdditionalCertificateBuilder> predicate) {
    for (ControlPlaneAdditionalCertificateBuilder item: additional) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withAdditional(List<ControlPlaneAdditionalCertificate> additional) {
    if (this.additional != null) { _visitables.get("additional").clear();}
    if (additional != null) {this.additional = new ArrayList(); for (ControlPlaneAdditionalCertificate item : additional){this.addToAdditional(item);}} else { this.additional = null;} return (A) this;
  }
  
  public A withAdditional(io.fabric8.openshift.api.model.hive.v1.ControlPlaneAdditionalCertificate... additional) {
    if (this.additional != null) {this.additional.clear(); _visitables.remove("additional"); }
    if (additional != null) {for (ControlPlaneAdditionalCertificate item :additional){ this.addToAdditional(item);}} return (A) this;
  }
  
  public boolean hasAdditional() {
    return additional != null && !additional.isEmpty();
  }
  
  public A addNewAdditional(String domain,String name) {
    return (A)addToAdditional(new ControlPlaneAdditionalCertificate(domain, name));
  }
  
  public AdditionalNested<A> addNewAdditional() {
    return new AdditionalNested(-1, null);
  }
  
  public AdditionalNested<A> addNewAdditionalLike(ControlPlaneAdditionalCertificate item) {
    return new AdditionalNested(-1, item);
  }
  
  public AdditionalNested<A> setNewAdditionalLike(int index,ControlPlaneAdditionalCertificate item) {
    return new AdditionalNested(index, item);
  }
  
  public AdditionalNested<A> editAdditional(int index) {
    if (additional.size() <= index) throw new RuntimeException("Can't edit additional. Index exceeds size.");
    return setNewAdditionalLike(index, buildAdditional(index));
  }
  
  public AdditionalNested<A> editFirstAdditional() {
    if (additional.size() == 0) throw new RuntimeException("Can't edit first additional. The list is empty.");
    return setNewAdditionalLike(0, buildAdditional(0));
  }
  
  public AdditionalNested<A> editLastAdditional() {
    int index = additional.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last additional. The list is empty.");
    return setNewAdditionalLike(index, buildAdditional(index));
  }
  
  public AdditionalNested<A> editMatchingAdditional(Predicate<ControlPlaneAdditionalCertificateBuilder> predicate) {
    int index = -1;
    for (int i=0;i<additional.size();i++) { 
    if (predicate.test(additional.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching additional. No match found.");
    return setNewAdditionalLike(index, buildAdditional(index));
  }
  
  public String getDefault() {
    return this._default;
  }
  
  public A withDefault(String _default) {
    this._default=_default; return (A) this;
  }
  
  public boolean hasDefault() {
    return this._default != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ControlPlaneServingCertificateSpecFluent that = (ControlPlaneServingCertificateSpecFluent) o;
    if (!java.util.Objects.equals(additional, that.additional)) return false;
  
    if (!java.util.Objects.equals(_default, that._default)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(additional,  _default,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (additional != null && !additional.isEmpty()) { sb.append("additional:"); sb.append(additional + ","); }
    if (_default != null) { sb.append("_default:"); sb.append(_default + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AdditionalNested<N> extends ControlPlaneAdditionalCertificateFluent<AdditionalNested<N>> implements Nested<N>{
    AdditionalNested(int index,ControlPlaneAdditionalCertificate item) {
      this.index = index;
      this.builder = new ControlPlaneAdditionalCertificateBuilder(this, item);
    }
    ControlPlaneAdditionalCertificateBuilder builder;
    int index;
    
    public N and() {
      return (N) ControlPlaneServingCertificateSpecFluent.this.setToAdditional(index,builder.build());
    }
    
    public N endAdditional() {
      return and();
    }
    
  
  }

}

==> openshift-model-hive-6.9.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ControlPlaneServingCertificateSpecFluent.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ControlPlaneServingCertificateSpecFluent<A extends ControlPlaneServingCertificateSpecFluent<A>> extends BaseFluent<A>{
  public ControlPlaneServingCertificateSpecFluent() {
  }
  
  public ControlPlaneServingCertificateSpecFluent(ControlPlaneServingCertificateSpec instance) {
    this.copyInstance(instance);
  }
  private ArrayList<ControlPlaneAdditionalCertificateBuilder> additional = new ArrayList<ControlPlaneAdditionalCertificateBuilder>();
  private String _default;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ControlPlaneServingCertificateSpec instance) {
    instance = (instance != null ? instance : new ControlPlaneServingCertificateSpec());
    if (instance != null) {
          this.withAdditional(instance.getAdditional());
          this.withDefault(instance.getDefault());
          this.withAdditional(instance.getAdditional());
          this.withDefault(instance.getDefault());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToAdditional(int index,ControlPlaneAdditionalCertificate item) {
    if (this.additional == null) {this.additional = new ArrayList<ControlPlaneAdditionalCertificateBuilder>();}
    ControlPlaneAdditionalCertificateBuilder builder = new ControlPlaneAdditionalCertificateBuilder(item);
    if (index < 0 || index >= additional.size()) { _visitables.get("additional").add(builder); additional.add(builder); } else { _visitables.get("additional").add(index, builder); additional.add(index, builder);}
    return (A)this;
  }
  
  public A setToAdditional(int index,ControlPlaneAdditionalCertificate item) {
    if (this.additional == null) {this.additional = new ArrayList<ControlPlaneAdditionalCertificateBuilder>();}
    ControlPlaneAdditionalCertificateBuilder builder = new ControlPlaneAdditionalCertificateBuilder(item);
    if (index < 0 || index >= additional.size()) { _visitables.get("additional").add(builder); additional.add(builder); } else { _visitables.get("additional").set(index, builder); additional.set(index, builder);}
    return (A)this;
  }
  
  public A addToAdditional(io.fabric8.openshift.api.model.hive.v1.ControlPlaneAdditionalCertificate... items) {
    if (this.additional == null) {this.additional = new ArrayList<ControlPlaneAdditionalCertificateBuilder>();}
    for (ControlPlaneAdditionalCertificate item : items) {ControlPlaneAdditionalCertificateBuilder builder = new ControlPlaneAdditionalCertificateBuilder(item);_visitables.get("additional").add(builder);this.additional.add(builder);} return (A)this;
  }
  
  public A addAllToAdditional(Collection<ControlPlaneAdditionalCertificate> items) {
    if (this.additional == null) {this.additional = new ArrayList<ControlPlaneAdditionalCertificateBuilder>();}
    for (ControlPlaneAdditionalCertificate item : items) {ControlPlaneAdditionalCertificateBuilder builder = new ControlPlaneAdditionalCertificateBuilder(item);_visitables.get("additional").add(builder);this.additional.add(builder);} return (A)this;
  }
  
  public A removeFromAdditional(io.fabric8.openshift.api.model.hive.v1.ControlPlaneAdditionalCertificate... items) {
    if (this.additional == null) return (A)this;
    for (ControlPlaneAdditionalCertificate item : items) {ControlPlaneAdditionalCertificateBuilder builder = new ControlPlaneAdditionalCertificateBuilder(item);_visitables.get("additional").remove(builder); this.additional.remove(builder);} return (A)this;
  }
  
  public A removeAllFromAdditional(Collection<ControlPlaneAdditionalCertificate> items) {
    if (this.additional == null) return (A)this;
    for (ControlPlaneAdditionalCertificate item : items) {ControlPlaneAdditionalCertificateBuilder builder = new ControlPlaneAdditionalCertificateBuilder(item);_visitables.get("additional").remove(builder); this.additional.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromAdditional(Predicate<ControlPlaneAdditionalCertificateBuilder> predicate) {
    if (additional == null) return (A) this;
    final Iterator<ControlPlaneAdditionalCertificateBuilder> each = additional.iterator();
    final List visitables = _visitables.get("additional");
    while (each.hasNext()) {
      ControlPlaneAdditionalCertificateBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ControlPlaneAdditionalCertificate> buildAdditional() {
    return this.additional != null ? build(additional) : null;
  }
  
  public ControlPlaneAdditionalCertificate buildAdditional(int index) {
    return this.additional.get(index).build();
  }
  
  public ControlPlaneAdditionalCertificate buildFirstAdditional() {
    return this.additional.get(0).build();
  }
  
  public ControlPlaneAdditionalCertificate buildLastAdditional() {
    return this.additional.get(additional.size() - 1).build();
  }
  
  public ControlPlaneAdditionalCertificate buildMatchingAdditional(Predicate<ControlPlaneAdditionalCertificateBuilder> predicate) {
      for (ControlPlaneAdditionalCertificateBuilder item : additional) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingAdditional(Predicate<ControlPlaneAdditionalCertificateBuilder> predicate) {
      for (ControlPlaneAdditionalCertificateBuilder item : additional) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withAdditional(List<ControlPlaneAdditionalCertificate> additional) {
    if (this.additional != null) {
      this._visitables.get("additional").clear();
    }
    if (additional != null) {
        this.additional = new ArrayList();
        for (ControlPlaneAdditionalCertificate item : additional) {
          this.addToAdditional(item);
        }
    } else {
      this.additional = null;
    }
    return (A) this;
  }
  
  public A withAdditional(io.fabric8.openshift.api.model.hive.v1.ControlPlaneAdditionalCertificate... additional) {
    if (this.additional != null) {this.additional.clear(); _visitables.remove("additional"); }
    if (additional != null) {for (ControlPlaneAdditionalCertificate item :additional){ this.addToAdditional(item);}} return (A) this;
  }
  
  public boolean hasAdditional() {
    return this.additional != null && !this.additional.isEmpty();
  }
  
  public A addNewAdditional(String domain,String name) {
    return (A)addToAdditional(new ControlPlaneAdditionalCertificate(domain, name));
  }
  
  public AdditionalNested<A> addNewAdditional() {
    return new AdditionalNested(-1, null);
  }
  
  public AdditionalNested<A> addNewAdditionalLike(ControlPlaneAdditionalCertificate item) {
    return new AdditionalNested(-1, item);
  }
  
  public AdditionalNested<A> setNewAdditionalLike(int index,ControlPlaneAdditionalCertificate item) {
    return new AdditionalNested(index, item);
  }
  
  public AdditionalNested<A> editAdditional(int index) {
    if (additional.size() <= index) throw new RuntimeException("Can't edit additional. Index exceeds size.");
    return setNewAdditionalLike(index, buildAdditional(index));
  }
  
  public AdditionalNested<A> editFirstAdditional() {
    if (additional.size() == 0) throw new RuntimeException("Can't edit first additional. The list is empty.");
    return setNewAdditionalLike(0, buildAdditional(0));
  }
  
  public AdditionalNested<A> editLastAdditional() {
    int index = additional.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last additional. The list is empty.");
    return setNewAdditionalLike(index, buildAdditional(index));
  }
  
  public AdditionalNested<A> editMatchingAdditional(Predicate<ControlPlaneAdditionalCertificateBuilder> predicate) {
    int index = -1;
    for (int i=0;i<additional.size();i++) { 
    if (predicate.test(additional.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching additional. No match found.");
    return setNewAdditionalLike(index, buildAdditional(index));
  }
  
  public String getDefault() {
    return this._default;
  }
  
  public A withDefault(String _default) {
    this._default = _default;
    return (A) this;
  }
  
  public boolean hasDefault() {
    return this._default != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ControlPlaneServingCertificateSpecFluent that = (ControlPlaneServingCertificateSpecFluent) o;
    if (!java.util.Objects.equals(additional, that.additional)) return false;
    if (!java.util.Objects.equals(_default, that._default)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(additional,  _default,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (additional != null && !additional.isEmpty()) { sb.append("additional:"); sb.append(additional + ","); }
    if (_default != null) { sb.append("_default:"); sb.append(_default + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AdditionalNested<N> extends ControlPlaneAdditionalCertificateFluent<AdditionalNested<N>> implements Nested<N>{
    AdditionalNested(int index,ControlPlaneAdditionalCertificate item) {
      this.index = index;
      this.builder = new ControlPlaneAdditionalCertificateBuilder(this, item);
    }
    ControlPlaneAdditionalCertificateBuilder builder;
    int index;
    
    public N and() {
      return (N) ControlPlaneServingCertificateSpecFluent.this.setToAdditional(index,builder.build());
    }
    
    public N endAdditional() {
      return and();
    }
    
  
  }

}
